locatieserver
===========================

|PyPI| |Python Version| |License| |Build| |Tests| |Codecov| |pre-commit| |Black|

.. |PyPI| image:: https://img.shields.io/pypi/v/locatieserver.svg
   :target: https://pypi.org/project/locatieserver/
   :alt: PyPI
.. |Python Version| image:: https://img.shields.io/pypi/pyversions/locatieserver
   :target: https://pypi.org/project/locatieserver
   :alt: Python Version
.. |License| image:: https://img.shields.io/github/license/foarsitter/locatieserver
   :target: https://opensource.org/licenses/MIT
   :alt: License
.. |Read the Docs| image:: https://img.shields.io/readthedocs/locatieserver/latest.svg?label=Read%20the%20Docs
   :target: https://locatieserver.readthedocs.io/
   :alt: Read the documentation at https://locatieserver.readthedocs.io/
.. |Build| image:: https://github.com/foarsitter/locatieserver/workflows/Build%20locatieserver%20Package/badge.svg
   :target: https://github.com/foarsitter/locatieserver/actions?workflow=Package
   :alt: Build Package Status
.. |Tests| image:: https://github.com/foarsitter/locatieserver/workflows/Run%20locatieserver%20Tests/badge.svg
   :target: https://github.com/foarsitter/locatieserver/actions?workflow=Tests
   :alt: Run Tests Status
.. |Codecov| image:: https://codecov.io/gh/foarsitter/locatieserver/branch/master/graph/badge.svg
   :target: https://codecov.io/gh/foarsitter/locatieserver
   :alt: Codecov
.. |pre-commit| image:: https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white
   :target: https://github.com/pre-commit/pre-commit
   :alt: pre-commit
.. |Black| image:: https://img.shields.io/badge/code%20style-black-000000.svg
   :target: https://github.com/psf/black
   :alt: Black

This repository contains a client for the PDOK locatieserver_.

.. _locatieserver: https://foarsitter.github.io/locatieserver/readme.html


Installation
------------

You can install *locatieserver* via pip_ from PyPI_:

.. code:: console

   $ pip install locatieserver


Usage
-----

See for https://foarsitter.github.io/locatieserver/usage.html usage



Credits
-------

This package was created with cookietemple_ using Cookiecutter_ based on Hypermodern_Python_Cookiecutter_.

.. _cookietemple: https://cookietemple.com
.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _PyPI: https://pypi.org/
.. _Hypermodern_Python_Cookiecutter: https://github.com/cjolowicz/cookiecutter-hypermodern-python
.. _pip: https://pip.pypa.io/
.. _Usage: https://locatieserver.readthedocs.io/en/latest/usage.html
